@@ -9,7 +9,7 @@
 
 int main(int argc, char *argv[])
 {
-  QApplication::setGraphicsSystem("native");
+//  QApplication::setGraphicsSystem("native");
   QApplication app(argc, argv);
   QCoreApplication::setOrganizationName("NSL");
   QCoreApplication::setOrganizationDomain("nsl.cz");
